@@ -7,7 +7,7 @@ import scipy.sparse
 import scipy.sparse.linalg
 
 # Datatypes
-bool = numpy.bool
+bool = bool
 float16 = numpy.float16
 float32 = numpy.float32
 float64 = numpy.float64
@@ -24,8 +24,10 @@ float_fmts.update({
 
 
 def asarray(x):
-    return array(x)
-
+    if hasattr(x, 'dtype'):
+        return array(x, dtype=x.dtype)
+    else:
+        return array(x)
 
 def to_float(x):
     return numpy.asanyarray(x).astype(float64)
@@ -263,11 +265,14 @@ def logical_xor(a, b, out=None, where=True):
 
 nonzero = numpy.nonzero
 argsort = numpy.argsort
+gather  = numpy.take 
 
-def solve_linear_system(A,b,overwrite_a=True,overwrite_b=True,check_finite=False,sparse=False):
+def solve_linear_system(A,b,overwrite_a=False,overwrite_b=False,check_finite=False,sparse=False):
     if sparse:
         return scipy.sparse.linalg.spsolve(scipy.sparse.csc_matrix(A),b)
     else:
         return scipy.linalg.solve(A,b,overwrite_a=overwrite_a,overwrite_b=overwrite_b,check_finite=check_finite)
 
 matrix_inv = numpy.linalg.inv
+eig = numpy.linalg.eig
+diag = numpy.diag
